Category

Enum Category 

pub enum Category {
    Io,
    Syntax,
    Data,
    Eof,
}
Categorizes the cause of a serde_json::Error.

Variants



Io

The error was caused by a failure to read or write bytes on an I/O stream.



Syntax

The error was caused by input that was not syntactically valid JSON.



Data

The error was caused by input data that was semantically incorrect.

For example, JSON containing a number is semantically incorrect when the type being deserialized into holds a String.



Eof

The error was caused by prematurely reaching the end of the input data.

Callers that process streaming input may be interested in retrying the deserialization once more data is available.